#ifndef DISPATCHER_H
#define DISPATCHER_H

#include <QString>
#include <QUrl>

#include "playlistparser.h"
#include "playlistloop.h"
#include "runnable.h"
#include "ui/viewer.h"
#include "remote.h"
#include "settings.h"

class Dispatcher : public QObject
{
    Q_OBJECT

public:
    Dispatcher(Viewer *viewer, QString path = QString()); // path is a dbus path

public slots:
    void next();
    void shootScreen();

private:
    enum Status {
        StatusNone = 0,
        StatusBrowser,
        StatusAfterBrowser,
        StatusPlaylist
    };

    Settings *settings;

    Dispatcher::Status m_status;
    Runnable *m_currentWidget;
    Runnable *m_prevWidget;
    QString m_mode;
    Viewer *m_viewer;
    QDateTime m_lastUpdate;
    Remote * remote;
    bool m_plRefresh;
    QTimer m_plTimer;

    PlaylistParser *m_pl;
    PlaylistLoop *m_loop;
    int m_loopIdx;

    bool m_idling;

    QTimer m_ssTimer;
    void disableScreensaver();

    void StartSession();
    void StopSession();
    void AddTime(int seconds);

    void startup();
    void reconnectMouseEvent();
    void afterBrowser();
    void startBrowser();
    void execHook(QString hook);
    QDateTime getLastEdit();

private slots:
    void onReconnectMouseEventTimeout();
    void onScreensaverTimeout();
    void onMouseEvent();
    void showLoopNext();
    void onPlTimeout();
    void startSlideshow();
    void goTo(int index);

};

#endif
