#ifndef VIEWER_H
#define VIEWER_H

#include <QTimer>
#include <QStackedWidget>
#include <QTime>

#include "runnable.h"
#include "settings.h"

class PlaylistEventFilter : public QObject
{
public:
    PlaylistEventFilter() : QObject(), m_paused(true) {};
    void setPaused(bool paused) { m_paused = paused; };

protected:
    bool eventFilter(QObject *obj, QEvent *event);

private:
    bool m_paused;
};


class BrowserEventFilter : public QObject
{
protected:
    bool eventFilter(QObject *obj, QEvent *event);
};


class Viewer : public QStackedWidget
{
    Q_OBJECT

public:
    Viewer();

    void emitMouseEvent();

    bool isReadyToShoot();

public slots:
    void resetTimer();
    void next(QWidget *widget);
    void pause();
    void showText(const QString & text, int duration);

protected:
    void closeEvent(QCloseEvent *event);

private:
    Settings *settings;
    QTimer m_timer;
    QTime m_time;

    int remainingTime;

    QWidget *prevWidget;

    PlaylistEventFilter *m_playlistEventFilter;
    BrowserEventFilter *m_browserEventFilter;
    QTimer m_unlockTimer;
    bool readyToShoot;
    void loadWindowSettings();
    void saveWindowSettings();
    void setShortcuts();
    void setTimer();

private slots:
    void bye();
    void onWidgetTimeout();
    void onTimerTimeout();
    void stop();
    void unlockPlaylistEventFilter();

signals:
    void end();
    void mouseEvent();
};

#endif
