#ifndef SETTINGSUI_H
#define SETTINGSUI_H

#include <QProcess>
#include <QtNetwork>

#include "settings.h"
#include "treeview.h"

#include "ui_webkioskSettings.h"

class SettingsDialog : public QDialog
{
    Q_OBJECT

public:
    SettingsDialog(QWidget *parent = 0);

private:
    Ui::SettingsDialog ui;

    Settings *settings;

    TreeView *m_localPlaylistView;

    QProcess *m_testProcess;

    QString token;

    void finalizeUi();
    void applySettings();

    void setText(QLineEdit *obj, const char *path);
    void setChecked(QCheckBox *obj, const char *path, bool value);
    void setSpin(QSpinBox *obj, const char *path);

    bool restrictionsLoadFromFile(QString &filename);
    bool restrictionsSaveToFile(QString &filename);
    void playlistLoadFromFile();
    void loadChannels();

private slots:
    void genPlaylistList();
    void genRestrictionsList();

    void on_restrictionsSelection_changed(const QItemSelection &selected,
                          const QItemSelection &deselected);
    void showError(QNetworkReply::NetworkError error);
    void on_helpBtn_clicked();
    void on_testFinished(int exitCode, QProcess::ExitStatus exitStatus);
    void on_testBtn_clicked();
    void on_cancelBtn_clicked();
    void on_okBtn_clicked();

    void on_useBtnGrp_buttonClicked(QAbstractButton *btn);
    void on_fullscreenChk_toggled(bool checked);
    void on_screenSaverChk_toggled(bool checked);
    void on_startupChk_toggled(bool checked);
    void on_passwordChk_toggled(bool checked);
    void on_passwordBtn_clicked();
    void on_fontBtn_clicked();

    void on_hideToolbarChk_toggled(bool checked);
    void on_browseFSChk_toggled(bool checked);
    void on_displayClearChk_toggled(bool checked);
    void on_printChk_toggled(bool checked);
    void on_sessionAtStartupChk_toggled(bool checked);
    void on_homeEdit_textChanged(QString value);
    void on_sessionTimeoutSpin_valueChanged(int value);
    void on_sessionTimeChk_toggled(bool checked);
    void on_sessionTimeSpin_valueChanged(int value);
    void on_postSessionUrlEdit_textEdited(QString value);
    void on_postSessionTimeSpin_valueChanged(int value);
    void on_restrictionsCombo_currentIndexChanged(int value);
    void on_regexChk_toggled(bool checked);
    void on_restrictionAddBtn_clicked();
    void on_restrictionDeleteBtn_clicked();
    void on_restrictionImportBtn_clicked();
    void on_restrictionExportBtn_clicked();

    void on_hideMouseChk_toggled(bool checked);
    void on_muteChk_toggled(bool checked);
    void on_displayTimeSpin_valueChanged(int value);
    void on_playlistBtnGrp_buttonClicked(QAbstractButton *btn);
    void on_playlistUsbUpdate_toggled(bool checked);
    void on_remoteEdit_textChanged(QString value);
    void on_refreshPlaylistSpin_valueChanged(int value);
    void on_localPlaylistDeleteBtn_clicked();
    void on_localPlaylistUpBtn_clicked();
    void on_localPlaylistDownBtn_clicked();
    void on_localPlaylistAddBtn_clicked();
    void on_localPlaylistCookiesBtn_clicked();
    void on_PlaylistSelectionChanged(const QItemSelection &,
                    const QItemSelection &);

    void on_proxyBtnGrp_buttonClicked(QAbstractButton *btn);
    void on_proxyUserEdit_textChanged(QString s);
    void on_proxyPasswordEdit_textChanged(QString s);
    void on_proxyUrlEdit_textChanged(QString s);
    void on_connect_clicked();
    void on_listWidget_itemClicked(QListWidgetItem *item);
};

#endif
